Module: DemoLorem
- Extended by:
- DemoLorem
- Included in:
- DemoLorem
- Defined in:
- lib/demo_lorem.rb,
lib/demo_lorem/version.rb
Constant Summary collapse
- VERSION =
"0.0.2"
Instance Method Summary collapse
- #cicero ⇒ Object
- #european_languages ⇒ Object
- #far_far_away ⇒ Object
- #ipsum ⇒ Object
- #kafka ⇒ Object
- #pangram ⇒ Object
- #random_regex ⇒ Object
- #weather ⇒ Object
Instance Method Details
#cicero ⇒ Object
13 14 15 16 17 |
# File 'lib/demo_lorem.rb', line 13 def cicero "But I must explain to you how all this mistaken idea of denouncing pleasure and praising pain was born and I will give you a complete account of the system, and expound the actual teachings of the great explorer of the truth, the master-builder of human happiness." end |
#european_languages ⇒ Object
19 20 21 22 23 24 |
# File 'lib/demo_lorem.rb', line 19 def european_languages "The European languages are members of the same family. Their separate existence is a myth. For science, music, sport, etc, Europe uses the same vocabulary. The languages only differ in their grammar, their pronunciation and their most common words. Everyone realizes why a new common language would be desirable" end |
#far_far_away ⇒ Object
26 27 28 29 30 31 |
# File 'lib/demo_lorem.rb', line 26 def far_far_away "Far far away, behind the word mountains, far from the countries Vokalia and Consonantia, there live the random texts. Separated they live in Bookmarksgrove right at the coast of the Semantics, a large language ocean. A small river named Duden flows by their place and supplies it with the necessary " end |
#ipsum ⇒ Object
5 6 7 8 9 10 11 |
# File 'lib/demo_lorem.rb', line 5 def ipsum "Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam,quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum." end |
#kafka ⇒ Object
39 40 41 42 43 |
# File 'lib/demo_lorem.rb', line 39 def kafka "One morning, when Gregor Samsa woke from troubled dreams, he found himself transformed in his bed into a horrible vermin. He lay on his armour-like back, and if he lifted his head a little he could see his brown belly, slightly domed and divided by arches into stiff sections." end |
#pangram ⇒ Object
45 46 47 48 49 |
# File 'lib/demo_lorem.rb', line 45 def pangram "The quick, brown fox jumps over a lazy dog. DJs flock by when MTV ax quiz prog. Junk MTV quiz graced by fox whelps. Bawds jog, flick quartz, vex nymphs. Waltz, bad nymph, for quick jigs vex! Fox nymphs grab quick-jived waltz. Brick quiz whangs jumpy veldt fox." end |
#random_regex ⇒ Object
51 52 53 54 55 |
# File 'lib/demo_lorem.rb', line 51 def random_regex "abc def ghi jkl mno pqrs tuv wxyz ABC DEF GHI JKL MNO PQRS TUV WXYZ ! $%& /() =?* <> #|; ²³~ @ ©«» ¤¼× {}abc def ghi jkl mno pqrs tuv wxyz ABC DEF GHI JKL MNO PQRS TUV WXYZ ! $%& /() =?* <> #|" end |
#weather ⇒ Object
33 34 35 36 37 |
# File 'lib/demo_lorem.rb', line 33 def weather "A wonderful serenity has taken possession of my entire soul, like these sweet mornings of spring which I enjoy with my whole heart. I am alone, and feel the charm of existence in this spot, which was created for the bliss of souls like mine." end |